.. currentmodule:: sardana.pool.poolgroupelement

:mod:`~sardana.pool.poolgroupelement`
======================================

.. automodule:: sardana.pool.poolgroupelement

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolBaseGroup`
    * :class:`PoolGroupElement`

PoolBaseGroup
-------------------

.. inheritance-diagram:: PoolBaseGroup
    :parts: 1
    
.. autoclass:: PoolBaseGroup
    :show-inheritance:
    :members:
    :undoc-members:

PoolGroupElement
--------------------------

.. inheritance-diagram:: PoolGroupElement
    :parts: 1
    
.. autoclass:: PoolGroupElement
    :show-inheritance:
    :members:
    :undoc-members:
